import React__default, { forwardRef, useRef, useImperativeHandle, useState, useLayoutEffect } from 'react';
import { useTheme } from '@rescui/ui-contexts';
import classNames from 'classnames';
import styles from './top-menu.module.pcss.js';
import { useTextStyles } from '@rescui/typography';
import { HorizontalMenu } from './horizontal-menu/horizontal-menu.js';
import { VerticalMenu } from './vertical-menu/vertical-menu.js';
import useResizeObserver from '@react-hook/resize-observer';
const BREAKPOINT_XS = 640;
const TopMenu = forwardRef(({
  homeUrl,
  title,
  mobileTitle,
  activeIndex,
  items,
  linkHandler = () => {},
  className,
  children,
  mobileOverview
}, forwardedRef) => {
  const theme = useTheme();
  const textCn = useTextStyles();
  const menuRef = useRef(null);
  useImperativeHandle(forwardedRef, () => menuRef.current);
  const [isMobileMenuVisible, setMobileMenuVisible] = useState(false);
  useLayoutEffect(() => {
    setMobileMenuVisible((menuRef.current?.getBoundingClientRect?.().width ?? 0) <= BREAKPOINT_XS);
  }, [menuRef]);
  useResizeObserver(menuRef, entry => setMobileMenuVisible(entry.contentRect.width <= BREAKPOINT_XS));
  return React__default.createElement("div", {
    ref: menuRef,
    className: classNames(styles.topMenu, className, {
      [styles.topMenuDarkTheme]: theme === 'dark'
    })
  }, React__default.createElement("a", {
    href: homeUrl,
    className: classNames(styles.logo, textCn('rs-h3')),
    onClick: event => linkHandler(event, homeUrl)
  }, title), isMobileMenuVisible ? React__default.createElement(VerticalMenu, {
    items: items,
    activeIndex: activeIndex,
    linkHandler: linkHandler,
    title: title,
    mobileTitle: mobileTitle,
    homeUrl: homeUrl,
    mobileOverview: mobileOverview,
    topMenuRef: menuRef
  }) : React__default.createElement(HorizontalMenu, {
    items: items,
    activeIndex: activeIndex,
    linkHandler: linkHandler
  }), children);
});
export { TopMenu };
